package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.dto.ConceptDTO;
import com.diagbot.entity.LibraryDetail;
import com.diagbot.entity.LibraryInfo;
import com.diagbot.service.impl.LibraryDetailServiceImpl;
import com.diagbot.vo.AmendTermVo;
import com.diagbot.vo.TermVo;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestBody;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description: 术语基本信息查询业务层
 * @author: Weixuan Huang
 * @time: 2019/1/16 14:17
 */
@Component
public class LibraryDetailFacade extends LibraryDetailServiceImpl {

    @Autowired
    private ConceptFacade conceptFacade;

    @Autowired
    private LibraryInfoFacade libraryInfoFacade;

    /**
     * 获取医学术语静态知识
     *
     * @param params
     * @result LibraryDetail
     */
    public List<LibraryDetail> getLibraryDetails(Map<String, Object> params) {
        QueryWrapper<LibraryDetail> wrapper = new QueryWrapper();
        List<LibraryDetail> libraryDetails;

        for (String key:params.keySet()) {
            wrapper.eq(key, params.get(key));
        }

        libraryDetails = this.list(wrapper);

        return libraryDetails;
    }

    /**
     * 获取医学术语静态信息
     *
     * @param termvo
     * @return ConceptDTO
     */
    public ConceptDTO getConceptKnowledge(@RequestBody TermVo termvo) {

        List<LibraryInfo> libraryInfos;
        LibraryInfo libraryInfo;
        List<LibraryDetail> libraryDetails;

        ConceptDTO conceptDTO = conceptFacade.getConcept(termvo);

        if (conceptDTO != null) {
            // 获取与医学术语的基本信息
            QueryWrapper<LibraryInfo> query = new QueryWrapper<>();
            query.eq("concept_id", conceptDTO.getId());
            query.eq("is_concept", 1);
            libraryInfos = libraryInfoFacade.list(query);

            if (libraryInfos != null) {
                libraryInfo = libraryInfos.get(0);
                conceptDTO.setName(libraryInfo.getName());

                // 获取与术语相关的静态知识
                QueryWrapper<LibraryDetail> querydetail = new QueryWrapper<>();
                querydetail.eq("concept_id", conceptDTO.getId());

                libraryDetails = list(querydetail);

                if (libraryDetails != null) {
                    conceptDTO.setInformation(libraryDetails);
                }
            }
        }

        return conceptDTO;
    }


    /**
     * 更新或添加医学术语静态信息
     *
     * @param amendTermVo
     * @return
     */
    public void upsertLibraryInfo(AmendTermVo amendTermVo) {

        if (amendTermVo.getInformation() != null && amendTermVo.getInformation().size() > 0) {
            for (int i=0; i<amendTermVo.getInformation().size(); i++) {
                LibraryDetail detail = amendTermVo.getInformation().get(i);
                int concept_id = detail.getConceptId().intValue();

                if (concept_id > 0) {
                    String title = detail.getTitle();

//                    TermVo termVo = new TermVo();
//                    termVo.setConcept_id(concept_id);

                    Map<String, Object> map = new HashMap<>();
                    map.put("concept_id", concept_id);
                    List<LibraryDetail> details = getLibraryDetails(map);

                    if (details != null && details.size() > 0) {
                        for (LibraryDetail item : details) {
                            if (item.getTitle().equals(title)) {
                                detail.setId(item.getId());
                                break;
                            }
                        }
                    }

                    this.saveOrUpdate(detail);
                }
            }
        }
        else {
            amendTermVo.setInformation(null);
        }
    }

    /**
     * 清空医学术语知识表
     *
     */
    public void deleteDetail() {
        truncateDetail();
    }
}
