package com.diagbot.web;


import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.ConceptDTO;
import com.diagbot.dto.LibraryInfoDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.facade.ConceptFacade;
import com.diagbot.vo.AmendTermVo;
import com.diagbot.vo.TermVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import com.baomidou.mybatisplus.core.metadata.*;

import javax.validation.Valid;
import java.util.List;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author Weixuan Huang
 * @since 2019-01-30
 */
@RestController
@RequestMapping("/concept")
@Api(value = "医学标准术语API", tags = { "医学标准术语API" })

public class ConceptController {
    @Autowired
    private ConceptFacade conceptFacade;


    @ApiOperation(value = "查询所有术语")
    @PostMapping("getAllConcept")
    @SysLogger("getAllConcept")
    public RespDTO<IPage<LibraryInfoDTO>> getAllConcept(@RequestBody TermVo termVo) {
        IPage<LibraryInfoDTO> data = conceptFacade.getAllConcepts(termVo);

        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "术语基本信息查询",
            notes = "Term：术语名称, 必填<br>Type：术语类型, 必填<br>")
    @PostMapping("/getConceptInfo")
    @SysLogger("getConceptInfo")
    public RespDTO<List<ConceptDTO>> getConceptInfo(@Valid @RequestBody TermVo termvo) {
        List<ConceptDTO> data = conceptFacade.getConceptInfo(termvo);

        return RespDTO.onSuc(data);
    }

    /*
    @ApiOperation(value = "术语静态知识查询",
            notes = "Term：术语名称, 必填<br>Type：术语类型, 必填<br>")
    @PostMapping("/getConceptKnowledge")
    @SysLogger("getConceptKnowledge")
    public RespDTO<TermDTO> getConceptKnowledge(@Valid @RequestBody TermVo termvo) {
        ConceptDTO data = conceptFacade.getConceptKnowledge(termvo);

        return RespDTO.onSuc(data);
    }
    *


    @ApiOperation(value = "术语医学信息查询",
            notes = "Term：术语名称, 必填<br>Type：术语类型, 必填<br>")
    @PostMapping("/getConceptMedInfo")
    @SysLogger("getConceptMedInfo")
    public RespDTO<TermDTO> getConceptMedInfo(@Valid @RequestBody TermVo termvo) {
        ConceptDTO data = conceptFacade.getConceptMedInfo(termvo);

        return RespDTO.onSuc(data);
    }

    /*
    @ApiOperation(value = "术语医学关系查询",
            notes = "Term：术语名称, 必填<br>Type：术语类型, 必填<br>")
    @PostMapping("/getConceptRelation")
    @SysLogger("getConceptRelation")
    public RespDTO<TermDTO> getConceptRelation(@Valid @RequestBody TermVo termvo) {
        ConceptDTO data = conceptFacade.getConceptRelation(termvo);

        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "术语修改",
            notes = "OldTerm: 原来的术语名称, 必填<br/>NewTerm: 新的术语名称, 必填<br/>" +
                    "Concept: 概念名称，必填<br/>Type: 新的术语类型, 必填<br/>")
    @PostMapping("/updateConceptInfo")
    @SysLogger("updateConceptInfo")
    public RespDTO<ConceptDTO> updateConceptInfo(@Valid @RequestBody AmendTermVo amendTermVo) {
        ConceptDTO data = conceptFacade.upsertConceptInfo(amendTermVo);

        return RespDTO.onSuc(data);
    }
    */

    @ApiOperation(value = "术语导入", notes = "导入术语信息")
    @PostMapping("/importTermExcel")
    public RespDTO<ConceptDTO> lisExcelAnalysis(@RequestParam("uploadfile") MultipartFile file) {
        ConceptDTO data = conceptFacade.importBatch(file);

        return RespDTO.onSuc(data);
    }

}
